@@ -39,7 +39,7 @@ class ImageRebuilder:
             rebuild_reason (str, optional): reason for the rebuild,
                                             used in commit
         """
-        self._base_image = base_image
+        self.base_image = base_image
 
         self._brewapi: KojiAPI = None
         self._distgit: DistgitAPI = None
@@ -150,12 +150,6 @@ class ImageRebuilder:
                                    self.latest_release)
         return self._brewapi
 
-    @property
-    def base_image(self):
-        if not self._base_image:
-            raise RebuilderError("Base image needs to be set.")
-        return self._base_image
-
     def _setup_logger(self, level=logging.INFO, user_logger=None, name=__name__):
         # If a logger is already set up, do not setup a new one
         if hasattr(self, "logger") and self.logger:
@@ -180,6 +174,7 @@ class ImageRebuilder:
         os.chdir(path)
 
     def _get_tmp_workdir(self, setup_dir: bool = True) -> str:
+        self._check_base(self.base_image)
         # Check if the workdir has been set by the user
         if self.tmp_workdir:
             return self.tmp_workdir
@@ -204,6 +199,10 @@ class ImageRebuilder:
     def set_do_set(self, val):
         self.do_set = val
 
+    def _check_base(self, base_image):
+        if not base_image:
+            raise RebuilderError("Base image needs to be set.")
+
     def _get_images(self) -> List:
         images: List = []
         if self.do_set:
